# Data

This folder contains various metadata related to our research. Brief description is provided here. More detailed description is given in the respective folders.

- [cert_ids](cert_ids) contains data related to evaluating `Certificate->certificate_id` matching
- [cpes](cpes) contains data related to evaluation of `Certificate->list of CPEs` matching
- [reference_annotations](reference_annotations) contains data and methodology related to annotating the references with their meaning.
- [sar_correlations](sar_correlations) contains data of correlations between SARs and number/severity of CVEs that affect the certificates.
- [information_retrieval](information_retrieval) contains data related to information retrieval experiments from certification artifacts.
